# jinjarg

CLI-template renderer like m4 but based on jinja2 and argparse.

## Installation

``` shell
pip install jinjarg
```

## Usage example

Take a look at [example](/example) directory.

## Why

There is jinja-cli and it's fine... until you need logic that doesn't fit in Jinja.
